==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.md <==
# AmazonBraketChandelier


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')
```



| Illustration | AmazonBraketChandelier | AmazonBraketChandelierCard | AmazonBraketChandelierGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.png) | ![illustration for AmazonBraketChandelier](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.Local.png) | ![illustration for AmazonBraketChandelierCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelierCard.Local.png) | ![illustration for AmazonBraketChandelierGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelierGroup.Local.png) |




## AmazonBraketChandelier

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelier
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelier('AmazonBraketChandelier', 'Amazon Braket Chandelier', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelier
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelier('AmazonBraketChandelier', 'Amazon Braket Chandelier', 'an optional tech label')
@enduml
```

## AmazonBraketChandelierCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierCard('AmazonBraketChandelierCard', 'Amazon Braket Chandelier Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierCard('AmazonBraketChandelierCard', 'Amazon Braket Chandelier Card', 'an optional description')
@enduml
```

## AmazonBraketChandelierGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierGroup('AmazonBraketChandelierGroup', 'Amazon Braket Chandelier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierGroup('AmazonBraketChandelierGroup', 'Amazon Braket Chandelier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.md <==
# AmazonBraketChandelier


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')
```



| Illustration | AmazonBraketChandelier | AmazonBraketChandelierCard | AmazonBraketChandelierGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.png) | ![illustration for AmazonBraketChandelier](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier.Local.png) | ![illustration for AmazonBraketChandelierCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelierCard.Local.png) | ![illustration for AmazonBraketChandelierGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelierGroup.Local.png) |




## AmazonBraketChandelier

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelier
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelier('AmazonBraketChandelier', 'Amazon Braket Chandelier', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelier
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelier('AmazonBraketChandelier', 'Amazon Braket Chandelier', 'an optional tech label')
@enduml
```

## AmazonBraketChandelierCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierCard('AmazonBraketChandelierCard', 'Amazon Braket Chandelier Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierCard('AmazonBraketChandelierCard', 'Amazon Braket Chandelier Card', 'an optional description')
@enduml
```

## AmazonBraketChandelierGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierGroup('AmazonBraketChandelierGroup', 'Amazon Braket Chandelier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketChandelierGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketChandelier')

' renders the element
AmazonBraketChandelierGroup('AmazonBraketChandelierGroup', 'Amazon Braket Chandelier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
